---
layout: default
title: exchangelib
---

## Exchange Web Services client library

This module provides an well-performing, well-behaving, platform-independent and simple interface 
for communicating with a Microsoft Exchange 2007-2016 Server or Office365 using Exchange Web Services 
(EWS). It currently implements autodiscover, and functions for searching, creating, updating, deleting, 
exporting and uploading calendar, mailbox, task and contact items
